#ifndef OTX_ETH_H
#define OTX_ETH_H
/*******************************************************************************

  Copyright (C) 2008 Odin TeleSystems Inc., All Rights Reserved

  @doc PublicHwApi OtxEth

  OTX Generic Hardware Driver API

  @module
  OtxEth | This file contains function prototypes for the T1/E1 Line Interface devices

  @contents2
  OtxEth.h |

  @index func | OtxEth

  @contents2
  OTX Ethernet Switch Device Functions - OtxEthXXX() |
  The user functions available for the Ethernet Switch Devices

  @head3 OtxEthXXX() Function Reference |

  @index func | OtxEth

*******************************************************************************/

#include "OtxDef.h"

#include "OtxEthD.h"

#ifdef __cplusplus
  extern "C" {
#endif


/*******************************************************************************

  @func
    This function retrieves the statistical counters for a specific port of the 
    Ethernet switch device. Ports 0-7 are DMP ports. Port 8 is the CPU port (used internally
    within the OTX driver). Port 9 is the GBE (WAN) port.

    The counters cover number of frames (of various types) that are transmitted and received.
    The also covers any error conditions that might have occured. 

  @ex |

      OTX_INT32 nPort;
      OtxEthStatCountersS sStatCounters;

      nPort = 9; // GBE (WAN) Port
      result = OtxEthGetStatCounters(g_hEthSw, nPort, &sStatCounters); DemoCheckRc(result);
      DemoLogf("   nTotalFramesReceived       : %-8d\n",  sStatCounters.nTotalFramesReceived      ); 
      DemoLogf("   nFlowCtrlFramesReceived    : %-8d\n",  sStatCounters.nFlowCtrlFramesReceived   ); 
      DemoLogf("   nMulticastFramesReceived   : %-8d\n",  sStatCounters.nMulticastFramesReceived  ); 
      DemoLogf("   nBroadcastFramesReceived   : %-8d\n",  sStatCounters.nBroadcastFramesReceived  ); 
      DemoLogf("   nUnicastFramesSent         : %-8d\n",  sStatCounters.nUnicastFramesSent        ); 
      DemoLogf("   nNonUnicastFrmsSent        : %-8d\n",  sStatCounters.nNonUnicastFrmsSent       ); 
      DemoLogf("   nFlowCtrlFramesSent        : %-8d\n",  sStatCounters.nFlowCtrlFramesSent       ); 
      DemoLogf("   nOversizeFrames            : %-8d\n",  sStatCounters.nOversizeFrames           ); 
      DemoLogf("   nJabberFrames              : %-8d\n",  sStatCounters.nJabberFrames             ); 
      DemoLogf("   nFragments                 : %-8d\n",  sStatCounters.nFragments                ); 
      DemoLogf("   nShortEvents               : %-8d\n",  sStatCounters.nShortEvents              ); 
      DemoLogf("   nFrameTransFailures        : %-8d\n",  sStatCounters.nFrameTransFailures       ); 
      DemoLogf("   nAlignmentErrors           : %-8d\n",  sStatCounters.nAlignmentErrors          ); 
      DemoLogf("   nUndersizeFrames           : %-8d\n",  sStatCounters.nUndersizeFrames          ); 
      DemoLogf("   nCrcErrors                 : %-8d\n",  sStatCounters.nCrcErrors                ); 
      DemoLogf("   nCollisions                : %-8d\n",  sStatCounters.nCollisions               ); 
      DemoLogf("   nFramesDroppedCongestion   : %-8d\n",  sStatCounters.nFramesDroppedCongestion  ); 
      DemoLogf("   nFramesFilteredByEngine    : %-8d\n",  sStatCounters.nFramesFilteredByEngine   ); 
      DemoLogf("   nLateCollision             : %-8d\n",  sStatCounters.nLateCollision            ); 

  @xref
    <t OtxEthStatCountersS>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxEthGetStatCounters(
  IN OTX_HANDLE             hDevice,         // @parm Handle to the Ethernet Switch Device
  IN OTX_INT32              nPort,           // @parm Port number of the Ethernet switch. 0-7 are DMP ports. 8 is the CPU. 9 is the GBE port.
  OUT OtxEthStatCountersS  *pStatCounters    // @parm Struct containing the statististical counters for this port
);


/*******************************************************************************

  @func
    This function provided the port status (link speed, link status, etc) of a
    specific port of the Ethernet Switch device.

  @ex |

      OTX_INT32 nPort;
      OtxEthPortStatusS sPortStatus;
      
      nPort = 9; // GBE (WAN) Port
      result = OtxEthGetPortStatus(g_hEthSw, nPort, &sPortStatus); DemoCheckRc(result);
      
      DemoLogf("Port Status for Ethernet Switch port %d (DMP)\n", nPort);
      DemoLogf("   Link Status : %s\n",  sPortStatus.bLinkUp ? "Up" : "Down"); 
      DemoLogf("   Link Speed  : %d\n",  sPortStatus.nLinkSpeed); 
      DemoLogf("   Flow Control: %s\n",  sPortStatus.bFlowControl ? "Yes" : "No"); 
      DemoLogf("   Full Duplex : %s\n",  sPortStatus.bFullDuplex ? "Yes" : "No"); 

  @xref
    <t OtxEthPortStatusS>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxEthGetPortStatus(
  IN OTX_HANDLE           hDevice,       // @parm Handle to the Ethernet Switch Device
  IN OTX_INT32            nPort,         // @parm Port number of the Ethernet switch. 0-7 are DMP ports. 8 is the CPU. 9 is the GBE port.
  OUT OtxEthPortStatusS  *pPortStatus    // @parm Struct containing the status of the specified port (link up/down, etc).
);


/*******************************************************************************

  @func
    This function sends a 40-byte control commandframe to the Ethernet switch and waits for 
    its response (also 40 bytes).

    It is only intended to be used by advanced users that will manually configure advanced
    features of the Ethernet switch device (e.g. port mirroring and VLAN). The switch can 
    be configured via this function and via calls to <f OtxDrvWriteReg8> (indirect register 
    access), and <f OtxDrvWriteReg16> (direct register access). 

  @ex |

      No example provided

  @xref
    <t OtxEthPortStatusS>
    <f OtxDrvWriteReg16>
    <f OtxDrvWriteReg8>
    <f OtxDrvReadReg16>
    <f OtxDrvReadReg8>
    <t OTX_ETH_CTRL_CMD_FRAME_SIZE>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxEthControlCommand(
  IN OTX_HANDLE           hDevice,       // @parm Handle to the Ethernet Switch Device
  IN OTX_UINT8           *pCmd,          // @parm Rontrol command (40 bytes)
  OUT OTX_UINT8          *pResponse      // @parm Response (40 bytes)
);




#ifdef __cplusplus
  } // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2008


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif   // OTX_ETH_H
